@@ -9,17 +9,17 @@
         <translation>via %1</translation>
     </message>
     <message>
-        <location filename="../src/activitywidget.cpp" line="121"/>
+        <location filename="../src/activitywidget.cpp" line="124"/>
         <source>To:</source>
         <translation>A:</translation>
     </message>
     <message>
-        <location filename="../src/activitywidget.cpp" line="124"/>
+        <location filename="../src/activitywidget.cpp" line="127"/>
         <source>CC:</source>
         <translation>CC:</translation>
     </message>
     <message>
-        <location filename="../src/activitywidget.cpp" line="141"/>
+        <location filename="../src/activitywidget.cpp" line="144"/>
         <source>Public</source>
         <translation>Pubblico</translation>
     </message>
@@ -60,6 +60,49 @@
         <translation>Carica meno recenti</translation>
     </message>
 </context>
+<context>
+    <name>EditProfileDialog</name>
+    <message>
+        <location filename="../src/editprofiledialog.cpp" line="42"/>
+        <source>&amp;Change picture</source>
+        <translation type="unfinished">Ca&amp;mbia immagine</translation>
+    </message>
+    <message>
+        <location filename="../src/editprofiledialog.cpp" line="49"/>
+        <source>Real name</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <location filename="../src/editprofiledialog.cpp" line="55"/>
+        <source>Hometown</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <location filename="../src/editprofiledialog.cpp" line="61"/>
+        <source>Bio</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <location filename="../src/editprofiledialog.cpp" line="138"/>
+        <source>Select Image</source>
+        <translation type="unfinished">Seleziona un&apos;immagine</translation>
+    </message>
+    <message>
+        <location filename="../src/editprofiledialog.cpp" line="139"/>
+        <source>Image files (*.png *.jpg *.jpeg *.gif);;All files (*.*)</source>
+        <translation type="unfinished">Files immagine (*.png *.jpg *.jpeg *.gif);;Tutti i files (*.*)</translation>
+    </message>
+    <message>
+        <location filename="../src/editprofiledialog.cpp" line="147"/>
+        <source>Sorry!</source>
+        <translation type="unfinished">Scusa!</translation>
+    </message>
+    <message>
+        <location filename="../src/editprofiledialog.cpp" line="148"/>
+        <source>That file didn&apos;t appear to be an image.</source>
+        <translation type="unfinished">Questo file non sembra essere un&apos;immagine.</translation>
+    </message>
+</context>
 <context>
     <name>FileDownloader</name>
     <message>
@@ -96,10 +139,14 @@
         <translation>modifica</translation>
     </message>
     <message>
-        <location filename="../src/fullobjectwidget.cpp" line="113"/>
-        <location filename="../src/fullobjectwidget.cpp" line="673"/>
         <source>comment</source>
-        <translation>commenta</translation>
+        <translation type="vanished">commenta</translation>
+    </message>
+    <message>
+        <location filename="../src/fullobjectwidget.cpp" line="113"/>
+        <source>comment</source>
+        <comment>Button to comment on a post</comment>
+        <translation type="unfinished">commenta</translation>
     </message>
     <message>
         <location filename="../src/fullobjectwidget.cpp" line="313"/>
@@ -107,10 +154,14 @@
         <translation>[Nessuna descrizione]</translation>
     </message>
     <message>
-        <location filename="../src/fullobjectwidget.cpp" line="349"/>
-        <location filename="../src/fullobjectwidget.cpp" line="366"/>
         <source>at %1</source>
-        <translation>in %1</translation>
+        <translation type="vanished">in %1</translation>
+    </message>
+    <message>
+        <location filename="../src/fullobjectwidget.cpp" line="349"/>
+        <source>at %1</source>
+        <comment>location of person</comment>
+        <translation type="unfinished">in %1</translation>
     </message>
     <message>
         <location filename="../src/fullobjectwidget.cpp" line="351"/>
@@ -122,6 +173,12 @@
         <source>updated %1</source>
         <translation>aggiornato %1</translation>
     </message>
+    <message>
+        <location filename="../src/fullobjectwidget.cpp" line="366"/>
+        <source>at %1</source>
+        <comment>time when post was published</comment>
+        <translation type="unfinished">in %1</translation>
+    </message>
     <message>
         <location filename="../src/fullobjectwidget.cpp" line="386"/>
         <source>unlike</source>
@@ -148,36 +205,72 @@
         <translation>segui</translation>
     </message>
     <message>
-        <location filename="../src/fullobjectwidget.cpp" line="624"/>
+        <location filename="../src/fullobjectwidget.cpp" line="547"/>
+        <source>shared this.</source>
+        <comment>Many persons shared</comment>
+        <translation type="unfinished">condiviso questo elemento.</translation>
+    </message>
+    <message>
+        <location filename="../src/fullobjectwidget.cpp" line="549"/>
+        <source>shared this.</source>
+        <comment>One person shared</comment>
+        <translation type="unfinished">condiviso questo elemento.</translation>
+    </message>
+    <message>
+        <location filename="../src/fullobjectwidget.cpp" line="629"/>
         <source>Show all replies</source>
         <translation>Mostra tutte le risposte</translation>
     </message>
+    <message>
+        <location filename="../src/fullobjectwidget.cpp" line="673"/>
+        <source>post</source>
+        <comment>Name of object type.</comment>
+        <translation type="unfinished">messaggio</translation>
+    </message>
+    <message>
+        <location filename="../src/fullobjectwidget.cpp" line="676"/>
+        <source>note</source>
+        <comment>Name of object type.</comment>
+        <translation type="unfinished">nota</translation>
+    </message>
+    <message>
+        <location filename="../src/fullobjectwidget.cpp" line="678"/>
+        <source>comment</source>
+        <comment>Name of object type.</comment>
+        <translation type="unfinished">commenta</translation>
+    </message>
+    <message>
+        <location filename="../src/fullobjectwidget.cpp" line="680"/>
+        <source>image</source>
+        <comment>Name of object type.</comment>
+        <translation type="unfinished">immagine</translation>
+    </message>
     <message>
         <source>stop following %1</source>
         <translation type="obsolete">smette di seguire %1</translation>
     </message>
     <message>
-        <location filename="../src/fullobjectwidget.cpp" line="440"/>
+        <location filename="../src/fullobjectwidget.cpp" line="442"/>
         <source>follow %1</source>
         <translation>segue %1</translation>
     </message>
     <message>
-        <location filename="../src/fullobjectwidget.cpp" line="510"/>
+        <location filename="../src/fullobjectwidget.cpp" line="512"/>
         <source>You like this.</source>
         <translation>Ti piace.</translation>
     </message>
     <message>
-        <location filename="../src/fullobjectwidget.cpp" line="512"/>
+        <location filename="../src/fullobjectwidget.cpp" line="514"/>
         <source>%1 likes this.</source>
         <translation>A %1 piace questo elemento.</translation>
     </message>
     <message>
-        <location filename="../src/fullobjectwidget.cpp" line="514"/>
+        <location filename="../src/fullobjectwidget.cpp" line="516"/>
         <source>%1 like this.</source>
         <translation>A %1 piace questo elemento.</translation>
     </message>
     <message numerus="yes">
-        <location filename="../src/fullobjectwidget.cpp" line="543"/>
+        <location filename="../src/fullobjectwidget.cpp" line="545"/>
         <source>and %Ln other person(s)</source>
         <translation>
             <numerusform>e %n un&apos;altra persona</numerusform>
@@ -195,13 +288,15 @@
             <numerusform>%n persons shared this.</numerusform>
         </translation>
     </message>
-    <message>
-        <location filename="../src/fullobjectwidget.cpp" line="544"/>
+    <message numerus="yes">
         <source>shared this.</source>
-        <translation>condiviso questo elemento.</translation>
+        <translation type="obsolete">
+            <numerusform>condiviso questo elemento.</numerusform>
+            <numerusform></numerusform>
+        </translation>
     </message>
     <message numerus="yes">
-        <location filename="../src/fullobjectwidget.cpp" line="547"/>
+        <location filename="../src/fullobjectwidget.cpp" line="552"/>
         <source>%Ln person(s) shared this.</source>
         <translation>
             <numerusform>%n persona ha condiviso questo elemento.</numerusform>
@@ -213,27 +308,24 @@
         <translation type="obsolete">Mostra tutte le %1 risposte</translation>
     </message>
     <message>
-        <location filename="../src/fullobjectwidget.cpp" line="668"/>
         <source>post</source>
-        <translation>messaggio</translation>
+        <translation type="vanished">messaggio</translation>
     </message>
     <message>
-        <location filename="../src/fullobjectwidget.cpp" line="671"/>
         <source>note</source>
-        <translation>nota</translation>
+        <translation type="vanished">nota</translation>
     </message>
     <message>
-        <location filename="../src/fullobjectwidget.cpp" line="675"/>
         <source>image</source>
-        <translation>immagine</translation>
+        <translation type="vanished">immagine</translation>
     </message>
     <message>
-        <location filename="../src/fullobjectwidget.cpp" line="696"/>
+        <location filename="../src/fullobjectwidget.cpp" line="701"/>
         <source>Are you sure you want to delete this %1?</source>
         <translation>Sei sicure di volere eliminare questo %1?</translation>
     </message>
     <message>
-        <location filename="../src/fullobjectwidget.cpp" line="716"/>
+        <location filename="../src/fullobjectwidget.cpp" line="721"/>
         <source>Share this %1 by %2?</source>
         <translation>Condividi questo %1 via %2?</translation>
     </message>
@@ -541,22 +633,22 @@
 <context>
     <name>PumpApp</name>
     <message>
-        <location filename="../src/pumpapp.cpp" line="158"/>
+        <location filename="../src/pumpapp.cpp" line="160"/>
         <source>&amp;Inbox</source>
         <translation>Messagg&amp;i ricevuti</translation>
     </message>
     <message>
-        <location filename="../src/pumpapp.cpp" line="159"/>
+        <location filename="../src/pumpapp.cpp" line="161"/>
         <source>&amp;Mentions</source>
         <translation>&amp;Menzioni</translation>
     </message>
     <message>
-        <location filename="../src/pumpapp.cpp" line="160"/>
+        <location filename="../src/pumpapp.cpp" line="162"/>
         <source>&amp;Direct</source>
         <translation>&amp;Diretti</translation>
     </message>
     <message>
-        <location filename="../src/pumpapp.cpp" line="161"/>
+        <location filename="../src/pumpapp.cpp" line="163"/>
         <source>Mean&amp;while</source>
         <translation>&amp;Nel frattempo</translation>
     </message>
@@ -565,7 +657,7 @@
         <translation type="obsolete">Copyright &amp;copy; 2013 Mats Sj&amp;ouml;berg</translation>
     </message>
     <message>
-        <location filename="../src/pumpapp.cpp" line="1096"/>
+        <location filename="../src/pumpapp.cpp" line="1154"/>
         <source>Fi&amp;rehose</source>
         <translation>Fi&amp;rehose</translation>
     </message>
@@ -574,108 +666,108 @@
         <translation type="obsolete">Hai ricevuto nuovi messaggi.</translation>
     </message>
     <message>
-        <location filename="../src/pumpapp.cpp" line="581"/>
+        <location filename="../src/pumpapp.cpp" line="579"/>
         <source>Error: </source>
         <translation>Errore:</translation>
     </message>
     <message>
-        <location filename="../src/pumpapp.cpp" line="640"/>
+        <location filename="../src/pumpapp.cpp" line="638"/>
         <source>%1 &amp;Window</source>
         <translation>%1 &amp;Finestra</translation>
     </message>
     <message>
-        <location filename="../src/pumpapp.cpp" line="640"/>
+        <location filename="../src/pumpapp.cpp" line="638"/>
         <source>Hide</source>
         <translation>Nascondi</translation>
     </message>
     <message>
-        <location filename="../src/pumpapp.cpp" line="640"/>
+        <location filename="../src/pumpapp.cpp" line="638"/>
         <source>Show</source>
         <translation>Mostra</translation>
     </message>
     <message>
-        <location filename="../src/pumpapp.cpp" line="655"/>
+        <location filename="../src/pumpapp.cpp" line="653"/>
         <source>E&amp;xit</source>
         <translation>E&amp;sci</translation>
     </message>
     <message>
-        <location filename="../src/pumpapp.cpp" line="656"/>
+        <location filename="../src/pumpapp.cpp" line="654"/>
         <source>Ctrl+Q</source>
         <translation>Ctrl+Q</translation>
     </message>
     <message>
-        <location filename="../src/pumpapp.cpp" line="659"/>
+        <location filename="../src/pumpapp.cpp" line="657"/>
         <source>Preferences</source>
         <translation>Preferenze</translation>
     </message>
     <message>
-        <location filename="../src/pumpapp.cpp" line="662"/>
+        <location filename="../src/pumpapp.cpp" line="660"/>
         <source>&amp;Reload timeline</source>
         <translation>&amp;Ricarica timeline</translation>
     </message>
     <message>
-        <location filename="../src/pumpapp.cpp" line="663"/>
+        <location filename="../src/pumpapp.cpp" line="661"/>
         <source>Ctrl+R</source>
         <translation>Ctrl+R</translation>
     </message>
     <message>
-        <location filename="../src/pumpapp.cpp" line="667"/>
+        <location filename="../src/pumpapp.cpp" line="665"/>
         <source>Load older in timeline</source>
         <translation>Carica elementi più vecchi nella timeline</translation>
     </message>
     <message>
-        <location filename="../src/pumpapp.cpp" line="668"/>
+        <location filename="../src/pumpapp.cpp" line="666"/>
         <source>Ctrl+O</source>
         <translation>Ctrl+O</translation>
     </message>
     <message>
-        <location filename="../src/pumpapp.cpp" line="671"/>
+        <location filename="../src/pumpapp.cpp" line="669"/>
         <source>F&amp;ollow an account</source>
         <translation>Segui un&apos;acc&amp;ount</translation>
     </message>
     <message>
-        <location filename="../src/pumpapp.cpp" line="672"/>
+        <location filename="../src/pumpapp.cpp" line="670"/>
         <source>Ctrl+L</source>
         <translation>Ctrl+L</translation>
     </message>
     <message>
-        <location filename="../src/pumpapp.cpp" line="675"/>
+        <location filename="../src/pumpapp.cpp" line="676"/>
         <source>&amp;About</source>
         <translation>A p&amp;roposito</translation>
     </message>
     <message>
-        <location filename="../src/pumpapp.cpp" line="678"/>
+        <location filename="../src/pumpapp.cpp" line="679"/>
         <source>About &amp;Qt</source>
         <translation>A proposito di &amp;Qt</translation>
     </message>
     <message>
-        <location filename="../src/pumpapp.cpp" line="684"/>
+        <location filename="../src/pumpapp.cpp" line="685"/>
         <source>New &amp;Note</source>
         <translation>&amp;Nuova Nota</translation>
     </message>
     <message>
-        <location filename="../src/pumpapp.cpp" line="685"/>
+        <location filename="../src/pumpapp.cpp" line="686"/>
         <source>Ctrl+N</source>
         <translation>Ctrl+N</translation>
     </message>
     <message>
-        <location filename="../src/pumpapp.cpp" line="689"/>
+        <location filename="../src/pumpapp.cpp" line="690"/>
         <source>Ctrl+D</source>
         <translation>Ctrl+D</translation>
     </message>
     <message>
-        <location filename="../src/pumpapp.cpp" line="316"/>
-        <location filename="../src/pumpapp.cpp" line="701"/>
+        <location filename="../src/pumpapp.cpp" line="314"/>
+        <location filename="../src/pumpapp.cpp" line="702"/>
         <source>Followers</source>
         <translation>Followers</translation>
     </message>
     <message>
-        <location filename="../src/pumpapp.cpp" line="248"/>
+        <location filename="../src/pumpapp.cpp" line="250"/>
         <source>SSL Error: </source>
         <translation>Errore SSL: </translation>
     </message>
     <message>
-        <location filename="../src/pumpapp.cpp" line="251"/>
+        <location filename="../src/pumpapp.cpp" line="253"/>
         <source>
 %1 is unable to verify the identity of the server. This error could mean that someone is trying to impersonate the server, or that the server&apos;s administrator has made an error.
 </source>
@@ -683,43 +775,43 @@
 %1 non è in grado di verificare l&apos;identità del server. Questo errore può significare che qualcuno sta provando a sostituire l&apos;identità del server, o che l&apos;amministratore del server ha commesso qualche errore.</translation>
     </message>
     <message>
-        <location filename="../src/pumpapp.cpp" line="259"/>
+        <location filename="../src/pumpapp.cpp" line="261"/>
         <source>SSL Server certificate.
 </source>
         <translation>Certificato Server SSL.</translation>
     </message>
     <message>
-        <location filename="../src/pumpapp.cpp" line="260"/>
+        <location filename="../src/pumpapp.cpp" line="262"/>
         <source>Issued to: </source>
         <translation>Rilasciato a:</translation>
     </message>
     <message>
-        <location filename="../src/pumpapp.cpp" line="261"/>
+        <location filename="../src/pumpapp.cpp" line="263"/>
         <source>Issued by: </source>
         <translation>Rilasciato da:</translation>
     </message>
     <message>
-        <location filename="../src/pumpapp.cpp" line="262"/>
+        <location filename="../src/pumpapp.cpp" line="264"/>
         <source>Effective: </source>
         <translation>Effettivo:</translation>
     </message>
     <message>
-        <location filename="../src/pumpapp.cpp" line="263"/>
+        <location filename="../src/pumpapp.cpp" line="265"/>
         <source>Expires: </source>
         <translation>Scade:</translation>
     </message>
     <message>
-        <location filename="../src/pumpapp.cpp" line="264"/>
+        <location filename="../src/pumpapp.cpp" line="266"/>
         <source>MD5 digest: </source>
         <translation>Digest MD5:</translation>
     </message>
     <message>
-        <location filename="../src/pumpapp.cpp" line="271"/>
+        <location filename="../src/pumpapp.cpp" line="273"/>
         <source>&lt;b&gt;Untrusted SSL connection!&lt;/b&gt;</source>
         <translation>&lt;b&gt;Connessione SSL non sicura!&lt;/b&gt;</translation>
     </message>
     <message>
-        <location filename="../src/pumpapp.cpp" line="310"/>
+        <location filename="../src/pumpapp.cpp" line="831"/>
         <source>Public</source>
         <translation>Pubblico</translation>
     </message>
@@ -728,72 +820,72 @@
         <translation type="obsolete">Hai %1 nuove notifiche.</translation>
     </message>
     <message>
-        <location filename="../src/pumpapp.cpp" line="506"/>
+        <location filename="../src/pumpapp.cpp" line="504"/>
         <source>%1 commented: </source>
         <translation>%1 ha commentato: </translation>
     </message>
     <message>
-        <location filename="../src/pumpapp.cpp" line="508"/>
+        <location filename="../src/pumpapp.cpp" line="506"/>
         <source>%1 wrote: </source>
         <translation>%1 ha scritto: </translation>
     </message>
     <message>
-        <location filename="../src/pumpapp.cpp" line="681"/>
+        <location filename="../src/pumpapp.cpp" line="682"/>
         <source>Report &amp;bug online</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../src/pumpapp.cpp" line="694"/>
+        <location filename="../src/pumpapp.cpp" line="695"/>
         <source>Ctrl+W</source>
         <translation>Ctrl+W</translation>
     </message>
     <message>
-        <location filename="../src/pumpapp.cpp" line="698"/>
+        <location filename="../src/pumpapp.cpp" line="699"/>
         <source>Firehose</source>
         <translation>Firehose</translation>
     </message>
     <message>
-        <location filename="../src/pumpapp.cpp" line="704"/>
+        <location filename="../src/pumpapp.cpp" line="705"/>
         <source>Following</source>
         <translation>Following</translation>
     </message>
     <message>
-        <location filename="../src/pumpapp.cpp" line="707"/>
+        <location filename="../src/pumpapp.cpp" line="708"/>
         <source>Favorites</source>
         <translation>Preferiti</translation>
     </message>
     <message>
-        <location filename="../src/pumpapp.cpp" line="711"/>
+        <location filename="../src/pumpapp.cpp" line="712"/>
         <source>Activities</source>
         <translation>Attività</translation>
     </message>
     <message>
-        <location filename="../src/pumpapp.cpp" line="722"/>
+        <location filename="../src/pumpapp.cpp" line="723"/>
         <source>&amp;Pumpa</source>
         <translation>&amp;Pumpa</translation>
     </message>
     <message>
-        <location filename="../src/pumpapp.cpp" line="734"/>
+        <location filename="../src/pumpapp.cpp" line="736"/>
         <source>&amp;Tabs</source>
         <translation>&amp;Tabs</translation>
     </message>
     <message>
-        <location filename="../src/pumpapp.cpp" line="743"/>
+        <location filename="../src/pumpapp.cpp" line="745"/>
         <source>&amp;Help</source>
         <translation>&amp;Aiuto</translation>
     </message>
     <message>
-        <location filename="../src/pumpapp.cpp" line="775"/>
+        <location filename="../src/pumpapp.cpp" line="777"/>
         <source>&lt;p&gt;Pumpa is free software: you can redistribute it and/or modify it under the terms of the GNU General Public License as published by the Free Software Foundation, either version 3 of the License, or (at your option) any later version.&lt;/p&gt;&lt;p&gt;Pumpa is distributed in the hope that it will be useful, but WITHOUT ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License for more details.&lt;/p&gt;&lt;p&gt;You should have received a copy of the GNU General Public License along with Pumpa.  If not, see &lt;a href=&quot;http://www.gnu.org/licenses/&quot;&gt;http://www.gnu.org/licenses/&lt;/a&gt;.&lt;/p&gt;</source>
         <translation>&lt;p&gt;Pumpa è free software: puoi redistribuirlo e/o modificarlo nei termini della licenza GNU General Public License come pubblicato dalla Free Software Foundation, nella versione 3 della licenza o (a tua scelta) una versione successiva.&lt;/p&gt;&lt;p&gt;Pumpa è distribuito nella speranza che ti sia utile, ma SENZA NESSUNA GARANZIA; senza nessuna implicita garanzia di COMMERCIABILITA&apos; o di ADEGUATEZZA PER UN PARTICOLARE SCOPO.  Vedere la GNU General Public License per più dettagli.&lt;/p&gt;&lt;p&gt;Dovresti aver ricevuto una copia della licenza GNU GPL con Pumpa.  In caso contrario, visita &lt;a href=&quot;http://www.gnu.org/licenses/&quot;&gt;http://www.gnu.org/licenses/&lt;/a&gt;.&lt;/p&gt;</translation>
     </message>
     <message>
-        <location filename="../src/pumpapp.cpp" line="788"/>
+        <location filename="../src/pumpapp.cpp" line="790"/>
         <source>&lt;p&gt;The &lt;a href=&quot;https://github.com/kypeli/kQOAuth&quot;&gt;kQOAuth library&lt;/a&gt; is copyrighted by &lt;a href=&quot;http://www.johanpaul.com/&quot;&gt;Johan Paul&lt;/a&gt; and licensed under LGPL 2.1.&lt;/p&gt;&lt;p&gt;The &lt;a href=&quot;https://github.com/vmg/sundown&quot;&gt;sundown Markdown library&lt;/a&gt; is copyrighted by Natacha Port&amp;eacute;, Vicent Marti and others, and &lt;a href=&quot;https://github.com/vmg/sundown#license&quot;&gt;permissively licensed&lt;/a&gt;.&lt;/p&gt;&lt;p&gt;The Pumpa logo was &lt;a href=&quot;http://opengameart.org/content/fruit-and-veggie-inventory&quot;&gt;created by Joshua Taylor&lt;/a&gt; for the &lt;a href=&quot;http://lpc.opengameart.org/&quot;&gt;Liberated Pixel Cup&lt;/a&gt;.The logo is copyrighted by the artist and is dual licensed under the CC-BY-SA 3.0 license and the GNU GPL 3.0.</source>
         <translation>&lt;p&gt;La &lt;a href=&quot;https://github.com/kypeli/kQOAuth&quot;&gt;libreria kQOAuth&lt;/a&gt; è proprietà di &lt;a href=&quot;http://www.johanpaul.com/&quot;&gt;Johan Paul&lt;/a&gt; ed è licenziata come LGPL 2.1.&lt;/p&gt;&lt;p&gt;La &lt;a href=&quot;https://github.com/vmg/sundown&quot;&gt;libreria sundown Markdown &lt;/a&gt; è proprietà di Natacha Port&amp;eacute;, Vicent Marti e altri, e &lt;a href=&quot;https://github.com/vmg/sundown#license&quot;&gt;resa disponibile con licenza permissiva&lt;/a&gt;.&lt;/p&gt;&lt;p&gt;Il logo di Pumpa è stato &lt;a href=&quot;http://opengameart.org/content/fruit-and-veggie-inventory&quot;&gt;creato da Joshua Taylor&lt;/a&gt; per la &lt;a href=&quot;http://lpc.opengameart.org/&quot;&gt;Liberated Pixel Cup&lt;/a&gt;.Il logo è proprietà dell&apos;artista ed è doppiamente licenziato come CC-BY-SA 3.0 e GNU GPL 3.0.</translation>
     </message>
     <message>
-        <location filename="../src/pumpapp.cpp" line="804"/>
+        <location filename="../src/pumpapp.cpp" line="806"/>
         <source>Copyright &amp;copy; 2013-2015 Mats Sj&amp;ouml;berg</source>
         <translation type="unfinished">Copyright &amp;copy; 2014 Mats Sj&amp;ouml;berg {2013-2015 ?}</translation>
     </message>
@@ -806,7 +898,7 @@
         <translation type="obsolete">Copyright &amp;copy; 2013 Mats Sj&amp;ouml;berg.&lt;/p&gt;</translation>
     </message>
     <message numerus="yes">
-        <location filename="../src/pumpapp.cpp" line="496"/>
+        <location filename="../src/pumpapp.cpp" line="494"/>
         <source>You have %Ln new notification(s).</source>
         <translation type="unfinished">
             <numerusform></numerusform>
@@ -814,112 +906,122 @@
         </translation>
     </message>
     <message>
-        <location filename="../src/pumpapp.cpp" line="807"/>
+        <location filename="../src/pumpapp.cpp" line="673"/>
+        <source>Your &amp;profile</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <location filename="../src/pumpapp.cpp" line="694"/>
+        <source>Close tab</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <location filename="../src/pumpapp.cpp" line="809"/>
         <source>&lt;p&gt;Report bugs and feature requests at &lt;a href=&quot;%5&quot;&gt;%5&lt;/a&gt;.&lt;/p&gt;</source>
         <translation>&lt;p&gt;Riporta problemi e richieste di funzionalità su &lt;a href=&quot;%5&quot;&gt;%5&lt;/a&gt;.&lt;/p&gt;</translation>
     </message>
     <message>
-        <location filename="../src/pumpapp.cpp" line="811"/>
+        <location filename="../src/pumpapp.cpp" line="813"/>
         <source>A simple Qt-based pump.io client.</source>
         <translation>Un semplice client pump.io basato su Qt.</translation>
     </message>
     <message>
-        <location filename="../src/pumpapp.cpp" line="815"/>
+        <location filename="../src/pumpapp.cpp" line="817"/>
         <source>About %1</source>
         <translation>A proposito di %1</translation>
     </message>
     <message>
-        <location filename="../src/pumpapp.cpp" line="922"/>
+        <location filename="../src/pumpapp.cpp" line="934"/>
         <source>Site not configured yet!</source>
         <translation>Sito non ancora configurato!</translation>
     </message>
     <message>
-        <location filename="../src/pumpapp.cpp" line="972"/>
+        <location filename="../src/pumpapp.cpp" line="984"/>
         <source>Follow pump.io user</source>
         <translation>Segui un utente pump.io</translation>
     </message>
     <message>
-        <location filename="../src/pumpapp.cpp" line="973"/>
+        <location filename="../src/pumpapp.cpp" line="985"/>
         <source>Enter webfinger ID of person to follow: </source>
         <translation>Inserisci il webfinger ID della persona che vuoi seguire:</translation>
     </message>
     <message>
-        <location filename="../src/pumpapp.cpp" line="983"/>
+        <location filename="../src/pumpapp.cpp" line="995"/>
         <source>Sorry, that doesn&apos;t even look like a webfinger ID!</source>
         <translation>Scusa, questo non sembra un webfinger ID!</translation>
     </message>
     <message>
-        <location filename="../src/pumpapp.cpp" line="988"/>
+        <location filename="../src/pumpapp.cpp" line="1000"/>
         <source>Sorry, you are already following that person!</source>
         <translation>Scusa, stai già seguendo questa persona!</translation>
     </message>
     <message>
-        <location filename="../src/pumpapp.cpp" line="1040"/>
+        <location filename="../src/pumpapp.cpp" line="1098"/>
         <source>Invalid user: </source>
         <translation>Utente non valido:</translation>
     </message>
     <message>
-        <location filename="../src/pumpapp.cpp" line="1047"/>
+        <location filename="../src/pumpapp.cpp" line="1105"/>
         <source>Invalid user (cannot check site): </source>
         <translation>Utente non valido (non riesco a verificare il sito):</translation>
     </message>
     <message>
-        <location filename="../src/pumpapp.cpp" line="1072"/>
+        <location filename="../src/pumpapp.cpp" line="1130"/>
         <source>&amp;Context</source>
         <translation>&amp;Contesto</translation>
     </message>
     <message>
-        <location filename="../src/pumpapp.cpp" line="1105"/>
+        <location filename="../src/pumpapp.cpp" line="1163"/>
         <source>&amp;Followers</source>
         <translation>Follo&amp;wers</translation>
     </message>
     <message>
-        <location filename="../src/pumpapp.cpp" line="1114"/>
+        <location filename="../src/pumpapp.cpp" line="1172"/>
         <source>F&amp;ollowing</source>
         <translation>F&amp;ollowing</translation>
     </message>
     <message>
-        <location filename="../src/pumpapp.cpp" line="1123"/>
+        <location filename="../src/pumpapp.cpp" line="1181"/>
         <source>F&amp;avorites</source>
         <translation>Pre&amp;feriti</translation>
     </message>
     <message>
-        <location filename="../src/pumpapp.cpp" line="1132"/>
+        <location filename="../src/pumpapp.cpp" line="1190"/>
         <source>A&amp;ctivities</source>
         <translation>Attiv&amp;ità</translation>
     </message>
     <message>
-        <location filename="../src/pumpapp.cpp" line="1451"/>
+        <location filename="../src/pumpapp.cpp" line="1528"/>
         <source>Loading ...</source>
         <translation>Caricamento ...</translation>
     </message>
     <message>
-        <location filename="../src/pumpapp.cpp" line="1513"/>
+        <location filename="../src/pumpapp.cpp" line="1590"/>
         <source>Ready!</source>
         <translation>Pronto!</translation>
     </message>
     <message>
-        <location filename="../src/pumpapp.cpp" line="1531"/>
+        <location filename="../src/pumpapp.cpp" line="1608"/>
         <source>Unable to post message!</source>
         <translation>Non riesco a postare il messaggio!</translation>
     </message>
     <message>
-        <location filename="../src/pumpapp.cpp" line="1535"/>
+        <location filename="../src/pumpapp.cpp" line="1612"/>
         <source>Unable to upload image!</source>
         <translation>Impossibile caricare l&apos;immagine!</translation>
     </message>
     <message>
-        <location filename="../src/pumpapp.cpp" line="1539"/>
+        <location filename="../src/pumpapp.cpp" line="1616"/>
         <source>Network or authorisation error [%1/%2] %3.</source>
         <translation>Errore di rete o di autorizzazione [%1/%2] %3.</translation>
     </message>
     <message>
-        <location filename="../src/pumpapp.cpp" line="1567"/>
+        <location filename="../src/pumpapp.cpp" line="1655"/>
         <source>Successfully followed </source>
         <translation>Following riuscito</translation>
     </message>
     <message>
-        <location filename="../src/pumpapp.cpp" line="1568"/>
+        <location filename="../src/pumpapp.cpp" line="1656"/>
         <source>Successfully unfollowed </source>
         <translation>Smesso di seguire correttamente </translation>
     </message>
